@@ -2,7 +2,7 @@
 Tekton pipeline's data collector
 
 """
-__version__="0.1.11"
+__version__="0.2.0"
 
 from atlassian import Jira
 import os
@@ -112,6 +112,21 @@ class Collector:
 
         return results
     
+    def get_artifact_id(self, path_to_pom_file):
+        if os.path.isdir(path_to_pom_file) and os.path.isfile(f"{path_to_pom_file}/pom.xml"):
+            with open(f"{path_to_pom_file}/pom.xml") as file:
+                xml_str = file.read()
+
+                # Parse the XML string with BeautifulSoup
+                soup = BeautifulSoup(xml_str, 'xml')
+
+                # Find the artifactId element within the project element
+                artifact_id = soup.select_one('project > artifactId')
+                if artifact_id.text: 
+                    return artifact_id.text
+        
+        return ""
+    
     def from_jira(self, issue_key):
 
         # retrieve the issue details
